import os
import argparse
from .scan_runner import ScanRunner
from .utils import Utils

LANGUAGES = ['ruby', 'javascript', 'typescript', 'python', 'php',
             'java', 'license', 'go', 'python2']
SCANNERS = ['sast', 'dast', 'sca', 'secrets']
BUILD_TOOLS = ['jenkins', 'travis']

def get_build_dir(command_args):
    build_dir = ''
    if command_args.path is not None:
        build_dir = command_args.path
    elif 'WORKSPACE' in os.environ:
        build_dir = os.environ['WORKSPACE']
    elif 'TRAVIS_BUILD_DIR' in os.environ:
        build_dir = os.environ['TRAVIS_BUILD_DIR']
    else:
        build_dir = os.getcwd()

    build_dir = Utils.add_path_separator(build_dir)

    return build_dir

def parse_command_line_params():
    parser = argparse.ArgumentParser(description='Sken Runner.')

    parser.add_argument('--api_id', metavar='API Id', help='API Id.')
    parser.add_argument('--app_id', metavar='Application Id', help='Application Id.')
    parser.add_argument('--scanner', metavar='Scanner', nargs='+', choices=SCANNERS, help='support scanners: ' + ','.join(SCANNERS))
    parser.add_argument('--lang', metavar='Language', nargs='+', choices=LANGUAGES, help='support languages: ' + ','.join(LANGUAGES))
    parser.add_argument('--path', metavar='Project path', help='path of the project to be scanned.')
    parser.add_argument('--build_tool', metavar='Build tool', choices=BUILD_TOOLS, help='Support build tools: ' + ','.join(BUILD_TOOLS))

    parser.add_argument('--var_dast_url', metavar='DAST URL', help='URL to be scanned.')
    parser.add_argument('--var_dast_full_scan', metavar='DAST full scan', choices=['yes', 'no'], help='DAST full scan or quick scan.')
    parser.add_argument('--var_dast_login_url', metavar='DAST login URL', help='DAST login URL.')
    parser.add_argument('--var_dast_login_body', metavar='DAST login body', help='DAST login body.')
    parser.add_argument('--var_dast_username', metavar='DAST login username', help='DAST login username.')
    parser.add_argument('--var_dast_password', metavar='DAST login password', help='DAST login password.')

    parser.add_argument('--var_findsecgubs_exclude_path', metavar='Exclude path of Findsecbugs scanner', help='Exclude path of Findsecbugs scanner.')
    parser.add_argument('--var_nodejsscan_exclude_path', metavar='Exclude path of NodeJsScan scanner', help='Exclude path of NodeJsScan scanner.')
    parser.add_argument('--var_maven_repo_path', metavar='Maven repo path', help='Maven repo path.')
    parser.add_argument('--var_gradle_repo_path', metavar='Gradle repo path', help='Gradle repo path.')
    parser.add_argument('--version', action='store_true', help='View skencli Version.')

    command_args = parser.parse_args()

    if command_args.version:
        print('Skencli: ' + version())
        exit(0)

    command_line_params = {
        'buildtool': command_args.build_tool,
        'scanner': command_args.scanner,
        'variables':  {
            'DAST_FULL_SCAN': command_args.var_dast_full_scan == 'yes',
            'DAST_URL': command_args.var_dast_url,
            'DAST_LOGINURL': command_args.var_dast_login_url,
            'DAST_LOGINBODY': command_args.var_dast_login_body,
            'DAST_USERNAME': command_args.var_dast_username,
            'DAST_PASSWORD': command_args.var_dast_password,
            'FINDSECBUGS_EXCLUDE_PATH': command_args.var_findsecgubs_exclude_path,
            'NODEJSSCAN_EXCLUDE_PATH': command_args.var_nodejsscan_exclude_path
        }
    }

    if command_args.scanner is not None:
        command_line_params['scanner'] = ','.join(command_args.scanner)
    if command_args.lang is not None:
        command_line_params['language'] = command_args.lang

    return command_line_params, command_args

def get_app_ids(command_args, yaml_config):
    api_id = ''
    app_id = ''

    if 'apiid' in yaml_config and yaml_config['apiid'] is not None:
        api_id = yaml_config['apiid']
    
    if command_args.api_id is not None:
        api_id = command_args.api_id

    if not api_id:
        print('Please specify "apiid" in sken.yaml or use --api_id flag.')
        exit(-1)

    if 'appid' in yaml_config and yaml_config['appid'] is not None:
        app_id = yaml_config['appid']
    
    if command_args.app_id is not None:
        app_id = command_args.app_id

    if not app_id:
        print('Please specify "apiid" in sken.yaml or use --api_id flag.')
        exit(-1)

    return api_id, app_id

def check_language(command_line_params, yaml_config):
    yaml_language = []
    if 'language' in yaml_config and yaml_config['language'] is not None:
        languages = yaml_config['language'].split(',')
        for language in languages:
            if language in LANGUAGES:
                yaml_language.append(language)
            else:
                print("Scanner for %s hasn't been supported." % language)

    if len(yaml_language) > 0:
        yaml_config['language'] = yaml_language
    elif 'language' in yaml_config:
        del yaml_config['language']

    return 'language' in yaml_config or 'language' in command_line_params

def version():
    return '0.1.56'

def main():
    command_line_params, command_args = parse_command_line_params()
    build_dir = get_build_dir(command_args)
    succeed, yaml_config = Utils.read_config(build_dir)
    api_id, app_id = get_app_ids(command_args, yaml_config)

    if not check_language(command_line_params, yaml_config):
        awsconfig = Utils.get_aws_config(app_id, api_id)
        command_line_params['language'] = Utils.detect_lang(awsconfig, build_dir, LANGUAGES)

    Utils.assert_docker_alive()
    # initial scan data items
    ScanRunner.run({
        'apiid': api_id, 
        'appid': app_id, 
        'buildDir': build_dir,
        'commandLine': command_line_params, 
        'yaml': yaml_config,
        'environment_variables': Utils.get_env_variables(command_args, yaml_config)
        })

if __name__ == "__main__":
    main()


import docker
import boto3
from botocore.config import Config
import base64
import subprocess
from datetime import datetime
import time
import sys
import os
import json
import ntpath
import shutil
import platform
from xml.dom.minidom import parse
import requests
import yaml
import logging

from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry

class DockerError(Exception):
    pass

class S3Error(Exception):
    pass

class Utils(object):
	sken_output_foler = ''
	linguist_image = '621002179714.dkr.ecr.us-east-1.amazonaws.com/linguist:latest'
	SKEN_SERVER_BASE_URL = 'https://cli.sken.ai/api/cli/v1'
	#SKEN_SERVER_BASE_URL = 'http://localhost:8080/api/cli/v1'
	http = None
	last_time_docker_login = 0
	minutes25 = 60*25

	@classmethod
	def get_retryable_http(cls):
		if cls.http is not None:
			return cls.http

		retry_strategy = Retry(
			total=10,
			backoff_factor=2,
			status_forcelist=[429, 500, 502, 503, 504],
			method_whitelist=["HEAD", "GET", "OPTIONS", "POST"]
		)

		adapter = HTTPAdapter(max_retries=retry_strategy)
		cls.http = requests.Session()
		cls.http.mount("https://", adapter)
		cls.http.mount("http://", adapter)

		return cls.http

	@classmethod
	def assert_docker_alive(cls):
		try:
			client = docker.from_env()
			client.ping()
		except Exception as e:
			print('No running docker client found, please ensure docker client is running.')
			print(str(e))
			exit(-1)

	@classmethod
	def docker_login(cls, scan_info):
		# no need to login again within 30 minutes
		now = cls.get_timestamp()
		if (now - cls.last_time_docker_login) < cls.minutes25:
			return docker.from_env()

		print('Logging in to docker')
		session = boto3.Session(
			aws_access_key_id=scan_info['accessKeyId'], 
			aws_secret_access_key=scan_info['secretAccessKey'], 
			region_name=scan_info['region'])

		ecr_client = session.client('ecr')
		token = ecr_client.get_authorization_token()
		ecr_username, ecr_password = base64.b64decode(token['authorizationData'][0]['authorizationToken']).decode().split(':')
		registry = token['authorizationData'][0]['proxyEndpoint']

		command = ['docker', 'login', '-u', ecr_username, '--password-stdin', registry]
		if sys.version_info < (3, 0):
			command = ['docker login -u ' + ecr_username + ' --password-stdin ' + registry]

		p = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, stdin=subprocess.PIPE, shell=True)
		stdout, stderr = p.communicate(input=ecr_password.encode('utf-8'))
		p.wait()

		if stdout is not None and stdout.decode('utf-8').find('Login Succeeded') >= 0:
			print('Login to docker succeeded.')
		else:
			raise DockerError('Login to docker failed: ' + stdout.decode('utf-8'))

		client = docker.from_env()
		cls.last_time_docker_login = cls.get_timestamp()
		"""
		client = docker.from_env()
		try:
			client.login(username=ecr_username, password=ecr_password, registry=registry, reauth=False)
		except Exception as e:
			print('Failed to login to docker: ' + str(e))
			exit(-1)
		"""

		return client

	@classmethod
	def docker_pull_image(cls, docker_client, image):
		"""
		command = ['docker', 'image', 'pull', image]
		if sys.version_info < (3, 0):
			command = ['docker image pull ' + image]
			
		p = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True)
		for line in iter(p.stdout.readline, b''):
			line = line.rstrip().decode('utf8')
			print(line)
		p.stdout.close()
		p.wait()
		"""
		try:
			docker_client.images.pull(image)
		except Exception as e:
			# pull failed, check if the image exists, if true then use the current version, otherwise raise error
			try:
				docker_client.images.get(image)
			except Exception as de:
				if sys.version_info < (3, 0):
					raise DockerError('Failed to pull image: ' + str(e))
				else:
					raise DockerError('Failed to pull image: ' + str(e)) from e

		
	@classmethod
	def get_timestamp(cls):
		now = datetime.now()
		try:
			return round(now.timestamp())
		except Exception as e:
			return int(round(time.mktime(now.timetuple())))

	@classmethod
	def get_formated_timestamp_timezone(cls):
		now = cls.get_timestamp()
		return datetime.strftime(datetime.utcfromtimestamp(now),'%Y-%m-%dT%H:%M:%SZ')

	@classmethod
	def get_formated_timestamp(cls):
		now = cls.get_timestamp()
		return datetime.strftime(datetime.utcfromtimestamp(now),'%Y%m%d%H%M%S')

	@classmethod
	def create_skenoutput_folder(cls, dir):
		cls.sken_output_foler = dir

		if not os.path.exists(dir):
			os.makedirs(dir)
			os.chmod(dir, 0o777)

	@classmethod
	def delete_skenoutput_folder(cls):
		shutil.rmtree(cls.sken_output_foler)

	@classmethod
	def save_stdout(cls, scanner, content):
		if not content:
			return
		if sys.version_info < (3, 0):
			content = content.encode('utf-8')

		with open(cls.sken_output_foler + os.path.sep + scanner + '-stdout.txt', 'w') as f:
			f.write(content)

	@classmethod
	def save_stderr(cls, scanner, content):
		if not content:
			return
		if sys.version_info < (3, 0):
			content = content.encode('utf-8')

		with open(cls.sken_output_foler + os.path.sep + scanner + '-stderr.txt', 'w') as f:
			f.write(content)

	@classmethod
	def detect_lang(cls, scan_info, build_dir, support_languages):
		print('Warning: no "language" specified in sken.yaml and --lang flag. Auto-detecting language...')
		client = cls.docker_login(scan_info)
		cls.docker_pull_image(client, cls.linguist_image)
		container = client.containers.run(cls.linguist_image, volumes={build_dir: {
			'bind': '/scan', 'mode': 'rw'}}, detach=True, tty=False, stdout=True, stderr=True)
		container.wait()
		print(container.logs().decode('UTF-8'))

		lang_file = build_dir + 'sken-lang.json'
		if not os.path.exists(lang_file):
			exit(-1)

		languages = []
		with open(lang_file, 'r') as f:
			data = json.load(f)
			detected_languages = data['languages']
			for language in detected_languages:
				if language.lower() in support_languages:
					languages.append(language.lower())
			
		if len(languages) > 0:
			print('Detected languages: ' + ', '.join(languages))
		else:
			print('No support languages detected.')
			exit(-1)

		if os.path.exists(lang_file):
			os.remove(lang_file)

		return languages

	@classmethod
	def _get_m2_from_settings(cls, settings_file):
		try:
			dom = parse(settings_file)
			root = dom.documentElement
			node_list = root.getElementsByTagName('localRepository')

			if node_list.length > 0:
				if node_list[0].childNodes.length > 0:
					return node_list[0].childNodes[0].data
		except Exception as e:
			return ''

	@classmethod
	def _get_maven_home(cls):
		command = ['mvn', '--version']
		if sys.version_info < (3, 0) or platform.system() == 'Linux':
			command = ['mvn --version']

		p = subprocess.Popen(command, stdout=subprocess.PIPE,
							stderr=subprocess.STDOUT, shell=True)

		maven_home = ''
		for line in iter(p.stdout.readline, b''):
			line = line.rstrip().decode('utf8')
			try:
				if line.index('Maven home') == 0:
					maven_home = line.split(': ')[1]
			except ValueError:
				continue
		p.stdout.close()
		p.wait()

		return maven_home

	@classmethod
	def find_m2_location(cls):
		# check if ${user.home}/.m2/settings.xml exists
		m2_location = ''
		user_home = cls.add_path_separator(os.path.expanduser('~'))

		if os.path.exists(user_home + '.m2/settings.xml'):
			m2_location = cls._get_m2_from_settings(user_home + '.m2/settings.xml')

		if m2_location:
			#print('found m2 location from user settings: ' + m2_location)
			return m2_location

		# find maven home
		maven_home = cls._get_maven_home()
		# check ${maven.home}/conf/settings.xml exists
		if maven_home:
			maven_home = cls.add_path_separator(maven_home)
			if os.path.exists(maven_home + 'conf/settings.xml'):
				m2_location = cls._get_m2_from_settings(maven_home + 'conf/settings.xml')

				if m2_location:
					#print('found m2 location from global settings: ' + m2_location)
					return m2_location
				else:
					# use default location
					return user_home + '.m2'

		return ''

	@classmethod
	def find_gradle_location(cls):
		# detect gradle user home
		user_home = cls.add_path_separator(os.path.expanduser('~'))

		gradle_user_home = user_home + '.gradle' + os.path.sep

		if 'GRADLE_USER_HOME' in os.environ and os.environ['GRADLE_USER_HOME'] is not None:
			gradle_user_home = cls.add_path_separator(os.environ['GRADLE_USER_HOME'])

		cache_location = gradle_user_home + 'caches' + os.path.sep + 'modules-2' + os.path.sep + 'files-2.1' + os.path.sep

		if os.path.exists(cache_location):
			return cache_location

		return ''

	@classmethod
	def add_path_separator(cls, path_str):
		if not path_str.endswith(os.path.sep):
			path_str = path_str + os.path.sep
		
		return path_str
	
	"""
	Read config from sken.yaml
	"""
	@classmethod
	def read_config(cls, build_dir):
		sken_config = {}
		succeed = False
		if os.path.exists(build_dir + 'sken.yaml'):
			with open(build_dir + 'sken.yaml', 'r') as stream:
				try:
					sken_config = yaml.safe_load(stream)
					succeed = True
				except yaml.YAMLError as exc:
					print('Read '+(build_dir + 'sken.yaml')+' failed, please check the content.')
					logging.exception(exc)
					exit(-1)
		else:
			print('File not found: %s' % (build_dir + 'sken.yaml'))

		return succeed, sken_config

	@classmethod
	def get_aws_config(cls, app_id, api_id):
		http = cls.get_retryable_http()
		try:
			resp = http.get(cls.SKEN_SERVER_BASE_URL + '/getAwsConfig', params={'appId': app_id, 'apiId': api_id})
			result = resp.json()

			if not result['success']:
				print('Failed to get aws config: ' + result['message'])
				exit(-1)

			return result

		except Exception as x:
			print('Failed to get aws config: ' + str(x))
			exit(-1)

	@classmethod
	def get_env_variables(cls, command_args, yaml_config):
		# home dir of jenkins and travis
		variables = {}
		if 'WORKSPACE' in os.environ:
			variables['jenkins_home_dir'] = os.environ['WORKSPACE']
		if 'TRAVIS_BUILD_DIR' in os.environ:
			variables['travis_home_dir'] = os.environ['TRAVIS_BUILD_DIR']
		
		# repo dir of maven and gradle
		if command_args.var_maven_repo_path is not None:
			variables['maven_repo_path'] = command_args.var_maven_repo_path
		elif 'variables' in yaml_config and 'MAVEN_REPO_PATH' in yaml_config['variables'] and yaml_config['variables']['MAVEN_REPO_PATH'] is not None:
			variables['maven_repo_path'] = yaml_config['variables']['MAVEN_REPO_PATH']
		else:
			variables['maven_repo_path'] = cls.find_m2_location()

		if command_args.var_gradle_repo_path is not None:
			variables['gradle_repo_path'] = command_args.var_gradle_repo_path
		elif 'variables' in yaml_config and 'GRADLE_REPO_PATH' in yaml_config['variables'] and yaml_config['variables']['GRADLE_REPO_PATH'] is not None:
			variables['gradle_repo_path'] = yaml_config['variables']['GRADLE_REPO_PATH']
		else:
			variables['gradle_repo_path'] = cls.find_gradle_location()

		return variables

	@classmethod
	def upload_output(cls, aws_config, app_id, output_file):
		print('Uploading output file...')
		timestamp = cls.get_formated_timestamp()
		file_name = ''

		try:
			config = Config(
				retries = dict(
					max_attempts = 3
				)
			)

			session = boto3.Session(
				aws_access_key_id=aws_config['accessKeyId'], 
				aws_secret_access_key=aws_config['secretAccessKey'], 
				region_name=aws_config['region'])

			s3 = session.resource('s3', config=config)
			file_name = ntpath.basename(output_file)
			data = open(output_file, 'rb')
			s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + timestamp + '/' + file_name, Body=data)
			
			print('Output file uploaded')
		except Exception as e:
			raise S3Error('Failed to upload output file: ' + str(e))

		return timestamp



import os
import json
import sys

from .utils import Utils, DockerError, S3Error
from threading import Timer

STATUS_RUNNING = 'RUNNING'
STATUS_ERROR = 'ERROR'

class ETLError(Exception):
    pass

class ScanRunner(object):
    aws_config = None
    scan_data_items = None
    api_id = None
    app_id = None
    build_dir = None
    etl_retry = False
    timer_delay = 0.01

    @classmethod
    def get_scan_data(cls, req):
        print('Getting scan data')
        http = Utils.get_retryable_http()
        try:
            headers = {"Content-Type": "application/json"}
            resp = http.post(Utils.SKEN_SERVER_BASE_URL +
                             '/getScanData', headers=headers, data=json.dumps(req))
            result = resp.json()

            if not result['success']:
                print('Failed to get scan data from server: ' +
                      result['message'])
                exit(-1)

            cls.aws_config = result['awsConfig']
            cls.scan_data_items = result['scanDataItems']

        except Exception as e:
            print('Failed to get scan data from server: ' + str(e))
            exit(-1)

    @classmethod
    def _create_etl_request(cls):
        req = {
            'appId': cls.app_id,
            'apiId': cls.api_id,
            'scanDataItems': cls.scan_data_items
        }

        return req

    @classmethod
    def _mark_error_item(cls):
        scan_data = None
        for item in cls.scan_data_items:
            if item['status'] == STATUS_RUNNING:
                scan_data = item
                break
        
        if scan_data is not None:
            scan_data['status'] = STATUS_ERROR
            return True
        else:
            return False

    @classmethod
    def do_etl(cls):
        print('ETL started')
        req = cls._create_etl_request()

        http = Utils.get_retryable_http()
        resp_text = ''

        try:
            headers = {"Content-Type": "application/json"}
            resp = http.post(Utils.SKEN_SERVER_BASE_URL +
                             '/doETL', headers=headers, data=json.dumps(req))
            resp_text = resp.text
            result = resp.json()

            if not result['success']:
                print(result['message'])
                # retry one more time  to mark current running item to error
                if not cls.etl_retry and cls._mark_error_item():
                    cls.etl_retry = True
                    Timer(cls.timer_delay, cls.do_etl).start()
                else:
                    cls.etl_retry = False
                    cls._mark_error_item()
                    Timer(cls.timer_delay, cls.run_next_scan).start()
            else:
                cls.etl_retry = False
                cls.scan_data_items = result['scanDataItems']
                Timer(cls.timer_delay, cls.run_next_scan).start()
        except Exception as e:
            print('Failed to trigger ETL: ' + str(e) + ', response: ' + resp_text)
            # retry one more time to mark current running item to error
            if not cls.etl_retry and cls._mark_error_item():
                cls.etl_retry = True
                Timer(cls.timer_delay, cls.do_etl).start()
            else:
                cls.etl_retry = False
                cls._mark_error_item()
                Timer(cls.timer_delay, cls.run_next_scan).start()

    @classmethod
    def run_docker(cls, scan_data):
        # docker login
        client = Utils.docker_login(cls.aws_config)
        scanner = scan_data['scanner']
        parameters = scan_data['parameters']
        # pull image
        docker_image = parameters['dockerImageURI']
        print('Pulling latest image for %s ' % scanner)
        Utils.docker_pull_image(client, docker_image)

        output_file = cls.build_dir + scan_data['outputFile']
        print('Scanning started')
        volumes = {cls.build_dir: {'bind': '/scan', 'mode': 'rw'}}

        if parameters['volumes'] is not None:
           volumes = parameters['volumes']

        command_line = ''
        if parameters['commandLine'] is not None:
           command_line = parameters['commandLine']

        try:
            container = client.containers.run(docker_image, command_line, volumes=volumes, detach=True, tty=False, stdout=True, stderr=True)
            container.wait()
        except Exception as de:
            if sys.version_info < (3, 0):
                raise DockerError('Failed to run docker image: ' + str(de))
            else:
                raise DockerError('Failed to run docker image: ' + str(de)) from de

        # write stdout and stderr output
        try:
            Utils.save_stdout(scanner, container.logs(stdout=True, stderr=False).decode('UTF-8'))
            Utils.save_stderr(scanner, container.logs(stdout=False, stderr=True).decode('UTF-8'))
        except Exception as e:
            pass

        if os.path.exists(output_file):
            print('Scanning completed. Output file: ' + output_file)
        else:
            print('Scanning completed')

        return output_file
        
    @classmethod
    def run_scan(cls, scan_data):
        # run docker
        try:
            print('Launching scanner %s ' % scan_data['scanner'])
            output_file = cls.run_docker(scan_data)
            # upload file
            file_empty = False
            if os.path.exists(output_file):
                file_empty = os.path.getsize(output_file) <= 0
            else:
                file_empty = True
            
            if not file_empty:
                timestampe = Utils.upload_output(cls.aws_config, cls.app_id, output_file)
                scan_data['timestamp'] = timestampe
                scan_data['fileEmpty'] = False
            else:
                scan_data['fileEmpty'] = True

            scan_data['endTime'] = Utils.get_formated_timestamp_timezone()

            cls.do_etl()
        except DockerError as e:
            print(str(e))
            # docker error found, set the current running data item to ERROR
            scan_data['status'] = STATUS_ERROR
            cls.do_etl()
        except S3Error as e:
            print(str(e))
            # S3 error found, set the current running data item to ERROR
            scan_data['status'] = STATUS_ERROR
            cls.do_etl()

    @classmethod
    def run_next_scan(cls):
        # pick up the scan data in running status
        scan_data = None
        for item in cls.scan_data_items:
            if item['status'] == STATUS_RUNNING:
                scan_data = item
                break

        if scan_data is None:
            # all completed/error
            # remove skenoutput folder if all scans succeed
            error_occurred = False
            for item in cls.scan_data_items:
                if item['status'] == STATUS_ERROR:
                    error_occurred = True
                    break
            if not error_occurred:
                Utils.delete_skenoutput_folder()

            exit(0)

        cls.run_scan(scan_data)

    @classmethod
    def run(cls, req):
        # get initial scan data items
        cls.app_id = req['appid']
        cls.api_id = req['apiid']
        cls.build_dir = req['buildDir']
        Utils.create_skenoutput_folder(cls.build_dir + os.path.sep + 'skenoutput')

        cls.get_scan_data(req)
        if len(cls.scan_data_items) == 0:
            print('No scans to run.')
            exit(-1)

        # pick up the scan data in running status
        scan_data = None
        for item in cls.scan_data_items:
            if item['status'] == STATUS_RUNNING:
                scan_data = item
                break

        if scan_data is None:
            print('No running scan found.')
            exit(-1)

        cls.run_scan(scan_data)



import setuptools
from skencli.sken_runner import version 

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='skencli',
    version=version(),
    author='Sken.ai',
    author_email='author@sken.ai',
    description='Sken CLI for running scanners',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='http://sken.ai/',
	install_requires=[
		'PyYAML>=5.1.2',
		'boto3>=1.10.26',
		'docker>=4.1.0',
		'netifaces>=0.10.9',
		'wget>=3.2',
        'requests>=2.7.0'
	],
	include_package_data=True,
    packages=setuptools.find_packages(),
	entry_points = {
        'console_scripts': ['skencli=skencli.sken_runner:main'],
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent'
    ],
    python_requires='>=2.7',
)